"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClientCache = void 0;
class ClientCache extends Map {
    constructor(cacheOptions) {
        super();
        Object.defineProperty(this, "lifeMap", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "maxSize", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.maxSize = cacheOptions.maxSize;
        this.lifeMap = new Map();
    }
    sweep(fn) {
        if (this.size === 0)
            return;
        for (const [key, value] of this) {
            const input = {
                value,
                timestamp: this.lifeMap.get(key),
                size: this.size,
            };
            if (fn(input, key)) {
                this.delete(key);
                this.lifeMap.delete(key);
            }
        }
    }
    set(key, value) {
        if (this.maxSize !== undefined && this.size >= this.maxSize) {
            return this;
        }
        this.lifeMap.set(key, Date.now());
        super.set(key, value);
        return this;
    }
    get(key) {
        if (this.has(key)) {
            return super.get(key);
        }
        return undefined;
    }
}
exports.ClientCache = ClientCache;
