"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SpiralAbyss = void 0;
const base_1 = require("./base");
const utils_1 = require("../utils");
class SpiralAbyss extends base_1.BaseRoute {
    constructor(options) {
        super(options);
        Object.defineProperty(this, "defaultOptions", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        this.defaultOptions = options?.defaultOptions;
    }
    /**
     * @param {string} uid Genshin Impact UID
     */
    async fetch(uid, options) {
        if (this.cache.has(uid))
            return this.cache.get(uid);
        const optionsToUse = (0, utils_1.mergeOptions)({
            options,
            cookieManager: this.cookieManager,
            defaultOptions: this.defaultOptions,
        }, "SpiralAbyssFetchOptions");
        if (!(0, utils_1.spiralAbyssValidator)(uid, optionsToUse)) {
            throw new Error("No UID or Cookie provided");
        }
        const { language, cookie, previous } = optionsToUse;
        const instance = new utils_1.RequestManager({
            withDS: true,
            withExtraHeaders: true,
            language,
        });
        const res = await instance.get("spiralAbyss", {
            Cookie: cookie,
        }, {
            server: (0, utils_1.checkServerRegion)(uid),
            role_id: uid,
            schedule_type: previous ? "2" : "1",
        });
        const { data } = res;
        this.cache.set(uid, data);
        return data;
    }
}
exports.SpiralAbyss = SpiralAbyss;
